@@ -5,7 +5,7 @@ use std::ops::Deref;
 use zeroize::Zeroize;
 
 #[cfg(feature = "secp256k1")]
-use libsecp256k1::{PublicKey as Secp256k1PublicKey, SecretKey as Secp256k1SecretKey};
+use secp256k1::{PublicKey as Secp256k1PublicKey, SecretKey as Secp256k1SecretKey};
 
 use curve25519_dalek::scalar::Scalar;
 use ed25519_dalek::{PublicKey as Ed25519PublicKey, SecretKey as Ed25519SecretKey};
@@ -67,7 +67,7 @@ impl Secp256k1ExtendedPrivKey {
         let (secret_key, chain_code) = result.split_at(32);
 
         let mut sk = Secp256k1ExtendedPrivKey {
-            secret_key: Secp256k1SecretKey::parse_slice(secret_key).map_err(Error::Secp256k1)?,
+            secret_key: Secp256k1SecretKey::from_slice(secret_key).map_err(Error::Secp256k1)?,
             chain_code: Protected::from(chain_code),
         };
 
@@ -78,21 +78,18 @@ impl Secp256k1ExtendedPrivKey {
         Ok(sk)
     }
 
-    pub fn secret(&self) -> [u8; 32] {
-        self.secret_key.serialize()
-    }
-
     pub fn child(&self, child: ChildNumber) -> Result<Secp256k1ExtendedPrivKey, Error> {
         let mut hmac: Hmac<Sha512> =
             Hmac::new_from_slice(&self.chain_code).map_err(|_| Error::InvalidChildNumber)?;
+        let secp = secp256k1::Secp256k1::new();
 
         if child.is_normal() {
             hmac.update(
-                &Secp256k1PublicKey::from_secret_key(&self.secret_key).serialize_compressed()[..],
+                &Secp256k1PublicKey::from_secret_key(&secp, &self.secret_key).serialize()[..],
             );
         } else {
             hmac.update(&[0]);
-            hmac.update(&self.secret_key.serialize()[..]);
+            hmac.update(self.secret_key.as_ref());
         }
 
         hmac.update(&child.to_bytes());
@@ -101,9 +98,9 @@ impl Secp256k1ExtendedPrivKey {
         let (secret_key, chain_code) = result.split_at(32);
 
         let mut secret_key =
-            Secp256k1SecretKey::parse_slice(&secret_key).map_err(Error::Secp256k1)?;
+            Secp256k1SecretKey::from_slice(&secret_key).map_err(Error::Secp256k1)?;
         secret_key
-            .tweak_add_assign(&self.secret_key)
+            .add_assign(self.secret_key.as_ref())
             .map_err(Error::Secp256k1)?;
 
         Ok(Secp256k1ExtendedPrivKey {
@@ -128,7 +125,7 @@ impl std::str::FromStr for Secp256k1ExtendedPrivKey {
 
         Ok(Secp256k1ExtendedPrivKey {
             chain_code: Protected::from(&data[13..45]),
-            secret_key: Secp256k1SecretKey::parse_slice(&data[46..78])
+            secret_key: Secp256k1SecretKey::from_slice(&data[46..78])
                 .map_err(|e| Error::Secp256k1(e))?,
         })
     }
@@ -225,11 +222,11 @@ mod tests_secp256k1 {
 
         assert_eq!(
             expected_secret_key,
-            &account.secret(),
+            account.secret_key.as_ref(),
             "Secret key is invalid"
         );
 
-        let secret_key = SecretKey::from_raw(&account.secret()).unwrap();
+        let secret_key = SecretKey::from_raw(account.secret_key.as_ref()).unwrap();
         let public_key = secret_key.public();
 
         assert_eq!(expected_address, public_key.address(), "Address is invalid");
@@ -242,11 +239,11 @@ mod tests_secp256k1 {
 
         assert_eq!(
             expected_secret_key,
-            &account.secret(),
+            account.secret_key.as_ref(),
             "Secret key is invalid"
         );
 
-        let secret_key = SecretKey::from_raw(&account.secret()).unwrap();
+        let secret_key = SecretKey::from_raw(account.secret_key.as_ref()).unwrap();
         let public_key = secret_key.public();
 
         assert_eq!(expected_address, public_key.address(), "Address is invalid");
@@ -256,7 +253,7 @@ mod tests_secp256k1 {
             .child(ChildNumber::from_str("1").unwrap())
             .unwrap();
 
-        let secret_key = SecretKey::from_raw(&account.secret()).unwrap();
+        let secret_key = SecretKey::from_raw(account.secret_key.as_ref()).unwrap();
         let public_key = secret_key.public();
 
         let expected_address: &[u8] =
@@ -268,7 +265,7 @@ mod tests_secp256k1 {
             .child(ChildNumber::from_str("2").unwrap())
             .unwrap();
 
-        let secret_key = SecretKey::from_raw(&account.secret()).unwrap();
+        let secret_key = SecretKey::from_raw(account.secret_key.as_ref()).unwrap();
         let public_key = secret_key.public();
         let expected_address: &[u8] =
             b"\x0a\x71\x5f\xfE\x21\x56\x79\xae\xF9\x40\xbF\x12\x9D\xf2\x9A\xCA\x07\x0A\xBF\xF8";
