@@ -26,9 +26,6 @@ pub use bip39::{Count, Mnemonic};
 pub use error::Error;
 pub use language::Language;
 
-#[cfg(feature = "user")]
-pub mod user;
-
 const PROOF_LENGTH: usize = 64; // use ed25519 signaure length.
 const DERIVE_CHAIN: &'static str = "m/44'/7364'";
 #[cfg(feature = "secp256k1")]
@@ -96,7 +93,7 @@ pub fn generate_btc_account(
 }
 
 #[derive(Default, Clone, Serialize, Deserialize, Eq, PartialEq, Hash, Debug)]
-pub struct Proof(Vec<u8>);
+pub struct Proof(pub Vec<u8>);
 
 impl Proof {
     pub fn prove(kp: &Keypair, maddr: &PeerId, raddr: &PeerId) -> Proof {
